Learn R Programming

helminthR (version 1.0.10)

findParasite: Find host-parasite interactions for a given parasite species.

Description

Given a host genus and/or species, this function returns a matrix containing host-parasite interaction data. Search available locations using data(locations).

Usage

findParasite(
  genus = NULL,
  species = NULL,
  group = NULL,
  subgroup = NULL,
  location = NULL,
  citation = FALSE,
  hostState = NULL,
  speciesOnly = FALSE,
  validateHosts = FALSE,
  removeDuplicates = FALSE
)

Value

Three (or five) column data.frame containing host species, parasite species (shortened name and full name), and citation link and number of citations (if citation = TRUE), with each row corresponding to an occurrence of a parasite species on a host species.

Arguments

genus

Parasite genus

species

Parasite species

group

Parasite group - Cestodes, Acanthocephalans, Monogeneans, Nematodes, Trematodes, or Turbellarian etc. (Turb)

subgroup

Parasite subgroup (family names largely)

location

Location of host-parasite interaction.

citation

Boolean. Should the output include the citation link and the number of supporting citations? default is FALSE

hostState

number corresponding to one of six different host states. The default value is NULL includes all host states

speciesOnly

boolean flag to remove host and parasite species where data are only available at genus level (default = FALSE)

validateHosts

boolean flag to check host species names against Catalogue of Life information and output taxonomic information (default = FALSE)

removeDuplicates

(boolean) should duplicate host-parasite combinations be removed? (default is FALSE)

Author

Tad Dallas

Details

hostState can take values 1-6 corresponding to if the recorded host was found

  • (1) "In the wild"

  • (2) "Zoo captivity"

  • (3) "Domesticated"

  • (4) "Experimental"

  • (5) "Commercial source"

  • (6) "Accidental infestation"

References

Gibson, D. I., Bray, R. A., & Harris, E. A. (Compilers) (2005). Host-Parasite Database of the Natural History Museum, London. <http://www.nhm.ac.uk/research-curation/scientific-resources/taxonomy-systematics/host-parasites/>

See Also

findHost

Examples

Run this code

strongHosts <- helminthR::findParasite(genus = "Strongyloides")

# An example of how to query multiple parasite species when 
# you have a vector of parasite species names

parasites <- c("Ascaris aculeati", "Oxyuris flagellum")
# \donttest{
 plyr::ldply(parasites, 
   function(x){
     helminthR::findParasite(unlist(strsplit(x, " "))[1], 
       unlist(strsplit(x," "))[2])
   }
 )
# }

Run the code above in your browser using DataLab