Learn R Programming

helminthR (version 1.0.10)

helminthR-package: Access London Natural History Museum host-helminth record database

Description

'helminthR': A programmatic interface to the London Natural History Museum's host-parasite database.

The package currently allows you to query by host species, parasite species, and geographic location. No information is provided on parasite prevalence or intensity.

Arguments

Author

Tad Dallas tad.a.dallas@gmail.com

References

Gibson, D. I., Bray, R. A., & Harris, E. A. (Compilers) (2005). Host-Parasite Database of the Natural History Museum, London. <http://www.nhm.ac.uk/research-curation/scientific-resources/taxonomy-systematics/host-parasites/>